=========
Changelog
=========

0.3.2 (2025-06-11)
==================

Small CSS bugfix.

* Fixed the appearance of tab titles (larger font-size and line height).
* Fixed the display-as-flex rule for the tab panel content when visible.

0.3.1 (2025-06-11)
==================

Fixed packaging mistake.

* Fixed missing Javascript assets in published package.

0.3.0 (2025-06-11)
==================

Feature and cleanup release.

* Restructured the documentation.
* [#6] The ``pdf`` module now has 100% test coverage.
* [#5] Ported the API project templates and static assets and made the landing page
  accessible.
* Improved the DX for running tests locally.
